# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class RelationshipToMany(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    An array of objects each containing the 'type' and 'id' for to-many relationships
    """


    class MetaOapg:
        unique_items = True
        
        @staticmethod
        def items() -> typing.Type['Linkage']:
            return Linkage

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple['Linkage'], typing.List['Linkage']],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'RelationshipToMany':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> 'Linkage':
        return super().__getitem__(i)

from papermerge_restapi_client.model.linkage import Linkage



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from papermerge_restapi_client import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401

from . import path

# query params


class FormatSchema(
    schemas.EnumBase,
    schemas.StrSchema
):


    class MetaOapg:
        enum_value_to_name = {
            "json": "JSON",
            "vnd.api+json": "VND_APIJSON",
        }
    
    @schemas.classproperty
    def JSON(cls):
        return cls("json")
    
    @schemas.classproperty
    def VND_APIJSON(cls):
        return cls("vnd.api+json")
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'format': typing.Union[FormatSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_format = api_client.QueryParameter(
    name="format",
    style=api_client.ParameterStyle.FORM,
    schema=FormatSchema,
    explode=True,
)
# body param


class SchemaForRequestBodyApplicationVndApijson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            ocr__language = schemas.StrSchema
            
            
            class ocr__trigger(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "auto": "AUTO",
                        "manual": "MANUAL",
                    }
                
                @schemas.classproperty
                def AUTO(cls):
                    return cls("auto")
                
                @schemas.classproperty
                def MANUAL(cls):
                    return cls("manual")
            localization__data_format = schemas.StrSchema
            localization__time_format = schemas.StrSchema
            localization__timezone = schemas.StrSchema
            __annotations__ = {
                "ocr__language": ocr__language,
                "ocr__trigger": ocr__trigger,
                "localization__data_format": localization__data_format,
                "localization__time_format": localization__time_format,
                "localization__timezone": localization__timezone,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr__language"]) -> MetaOapg.properties.ocr__language: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr__trigger"]) -> MetaOapg.properties.ocr__trigger: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["localization__data_format"]) -> MetaOapg.properties.localization__data_format: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["localization__time_format"]) -> MetaOapg.properties.localization__time_format: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["localization__timezone"]) -> MetaOapg.properties.localization__timezone: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ocr__language", "ocr__trigger", "localization__data_format", "localization__time_format", "localization__timezone", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr__language"]) -> typing.Union[MetaOapg.properties.ocr__language, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr__trigger"]) -> typing.Union[MetaOapg.properties.ocr__trigger, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["localization__data_format"]) -> typing.Union[MetaOapg.properties.localization__data_format, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["localization__time_format"]) -> typing.Union[MetaOapg.properties.localization__time_format, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["localization__timezone"]) -> typing.Union[MetaOapg.properties.localization__timezone, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ocr__language", "ocr__trigger", "localization__data_format", "localization__time_format", "localization__timezone", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        ocr__language: typing.Union[MetaOapg.properties.ocr__language, str, schemas.Unset] = schemas.unset,
        ocr__trigger: typing.Union[MetaOapg.properties.ocr__trigger, str, schemas.Unset] = schemas.unset,
        localization__data_format: typing.Union[MetaOapg.properties.localization__data_format, str, schemas.Unset] = schemas.unset,
        localization__time_format: typing.Union[MetaOapg.properties.localization__time_format, str, schemas.Unset] = schemas.unset,
        localization__timezone: typing.Union[MetaOapg.properties.localization__timezone, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaForRequestBodyApplicationVndApijson':
        return super().__new__(
            cls,
            *args,
            ocr__language=ocr__language,
            ocr__trigger=ocr__trigger,
            localization__data_format=localization__data_format,
            localization__time_format=localization__time_format,
            localization__timezone=localization__timezone,
            _configuration=_configuration,
            **kwargs,
        )


class SchemaForRequestBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            ocr__language = schemas.StrSchema
            
            
            class ocr__trigger(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "auto": "AUTO",
                        "manual": "MANUAL",
                    }
                
                @schemas.classproperty
                def AUTO(cls):
                    return cls("auto")
                
                @schemas.classproperty
                def MANUAL(cls):
                    return cls("manual")
            localization__data_format = schemas.StrSchema
            localization__time_format = schemas.StrSchema
            localization__timezone = schemas.StrSchema
            __annotations__ = {
                "ocr__language": ocr__language,
                "ocr__trigger": ocr__trigger,
                "localization__data_format": localization__data_format,
                "localization__time_format": localization__time_format,
                "localization__timezone": localization__timezone,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr__language"]) -> MetaOapg.properties.ocr__language: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ocr__trigger"]) -> MetaOapg.properties.ocr__trigger: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["localization__data_format"]) -> MetaOapg.properties.localization__data_format: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["localization__time_format"]) -> MetaOapg.properties.localization__time_format: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["localization__timezone"]) -> MetaOapg.properties.localization__timezone: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ocr__language", "ocr__trigger", "localization__data_format", "localization__time_format", "localization__timezone", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr__language"]) -> typing.Union[MetaOapg.properties.ocr__language, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ocr__trigger"]) -> typing.Union[MetaOapg.properties.ocr__trigger, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["localization__data_format"]) -> typing.Union[MetaOapg.properties.localization__data_format, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["localization__time_format"]) -> typing.Union[MetaOapg.properties.localization__time_format, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["localization__timezone"]) -> typing.Union[MetaOapg.properties.localization__timezone, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ocr__language", "ocr__trigger", "localization__data_format", "localization__time_format", "localization__timezone", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        ocr__language: typing.Union[MetaOapg.properties.ocr__language, str, schemas.Unset] = schemas.unset,
        ocr__trigger: typing.Union[MetaOapg.properties.ocr__trigger, str, schemas.Unset] = schemas.unset,
        localization__data_format: typing.Union[MetaOapg.properties.localization__data_format, str, schemas.Unset] = schemas.unset,
        localization__time_format: typing.Union[MetaOapg.properties.localization__time_format, str, schemas.Unset] = schemas.unset,
        localization__timezone: typing.Union[MetaOapg.properties.localization__timezone, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaForRequestBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            ocr__language=ocr__language,
            ocr__trigger=ocr__trigger,
            localization__data_format=localization__data_format,
            localization__time_format=localization__time_format,
            localization__timezone=localization__timezone,
            _configuration=_configuration,
            **kwargs,
        )


request_body_any_type = api_client.RequestBody(
    content={
        'application/vnd.api+json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationVndApijson),
        'application/json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson),
    },
)
_auth = [
    'Token Authentication',
]


class SchemaFor200ResponseBodyApplicationVndApijson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            
            
            class data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                
                                
                                class additional_data(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            choices = schemas.Schema
                                            __annotations__ = {
                                                "choices": choices,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["choices"]) -> MetaOapg.properties.choices: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["choices", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["choices"]) -> typing.Union[MetaOapg.properties.choices, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["choices", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        choices: typing.Union[MetaOapg.properties.choices, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'additional_data':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            choices=choices,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                default = schemas.StrSchema
                                
                                
                                class field(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            _class = schemas.StrSchema
                                            input_type = schemas.StrSchema
                                            __annotations__ = {
                                                "class": _class,
                                                "input_type": input_type,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["class"]) -> MetaOapg.properties._class: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["input_type"]) -> MetaOapg.properties.input_type: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["class", "input_type", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["class"]) -> typing.Union[MetaOapg.properties._class, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["input_type"]) -> typing.Union[MetaOapg.properties.input_type, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["class", "input_type", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        input_type: typing.Union[MetaOapg.properties.input_type, str, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'field':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            input_type=input_type,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                help_text = schemas.StrSchema
                                id = schemas.StrSchema
                                identifier = schemas.StrSchema
                                name = schemas.StrSchema
                                section = schemas.StrSchema
                                value = schemas.StrSchema
                                __annotations__ = {
                                    "additional_data": additional_data,
                                    "default": default,
                                    "field": field,
                                    "help_text": help_text,
                                    "id": id,
                                    "identifier": identifier,
                                    "name": name,
                                    "section": section,
                                    "value": value,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["additional_data"]) -> MetaOapg.properties.additional_data: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["default"]) -> MetaOapg.properties.default: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["help_text"]) -> MetaOapg.properties.help_text: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["identifier"]) -> MetaOapg.properties.identifier: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["section"]) -> MetaOapg.properties.section: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["additional_data", "default", "field", "help_text", "id", "identifier", "name", "section", "value", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["additional_data"]) -> typing.Union[MetaOapg.properties.additional_data, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["default"]) -> typing.Union[MetaOapg.properties.default, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["field"]) -> typing.Union[MetaOapg.properties.field, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["help_text"]) -> typing.Union[MetaOapg.properties.help_text, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["identifier"]) -> typing.Union[MetaOapg.properties.identifier, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["section"]) -> typing.Union[MetaOapg.properties.section, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["additional_data", "default", "field", "help_text", "id", "identifier", "name", "section", "value", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            additional_data: typing.Union[MetaOapg.properties.additional_data, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            default: typing.Union[MetaOapg.properties.default, str, schemas.Unset] = schemas.unset,
                            field: typing.Union[MetaOapg.properties.field, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            help_text: typing.Union[MetaOapg.properties.help_text, str, schemas.Unset] = schemas.unset,
                            id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                            identifier: typing.Union[MetaOapg.properties.identifier, str, schemas.Unset] = schemas.unset,
                            name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                            section: typing.Union[MetaOapg.properties.section, str, schemas.Unset] = schemas.unset,
                            value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                additional_data=additional_data,
                                default=default,
                                field=field,
                                help_text=help_text,
                                id=id,
                                identifier=identifier,
                                name=name,
                                section=section,
                                value=value,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'data':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        data: typing.Union[MetaOapg.properties.data, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationVndApijson':
        return super().__new__(
            cls,
            *args,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            
            
            class data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                
                                
                                class additional_data(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            choices = schemas.Schema
                                            __annotations__ = {
                                                "choices": choices,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["choices"]) -> MetaOapg.properties.choices: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["choices", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["choices"]) -> typing.Union[MetaOapg.properties.choices, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["choices", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        choices: typing.Union[MetaOapg.properties.choices, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'additional_data':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            choices=choices,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                default = schemas.StrSchema
                                
                                
                                class field(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            _class = schemas.StrSchema
                                            input_type = schemas.StrSchema
                                            __annotations__ = {
                                                "class": _class,
                                                "input_type": input_type,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["class"]) -> MetaOapg.properties._class: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["input_type"]) -> MetaOapg.properties.input_type: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["class", "input_type", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["class"]) -> typing.Union[MetaOapg.properties._class, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["input_type"]) -> typing.Union[MetaOapg.properties.input_type, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["class", "input_type", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        input_type: typing.Union[MetaOapg.properties.input_type, str, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'field':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            input_type=input_type,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                help_text = schemas.StrSchema
                                id = schemas.StrSchema
                                identifier = schemas.StrSchema
                                name = schemas.StrSchema
                                section = schemas.StrSchema
                                value = schemas.StrSchema
                                __annotations__ = {
                                    "additional_data": additional_data,
                                    "default": default,
                                    "field": field,
                                    "help_text": help_text,
                                    "id": id,
                                    "identifier": identifier,
                                    "name": name,
                                    "section": section,
                                    "value": value,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["additional_data"]) -> MetaOapg.properties.additional_data: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["default"]) -> MetaOapg.properties.default: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["help_text"]) -> MetaOapg.properties.help_text: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["identifier"]) -> MetaOapg.properties.identifier: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["section"]) -> MetaOapg.properties.section: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["additional_data", "default", "field", "help_text", "id", "identifier", "name", "section", "value", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["additional_data"]) -> typing.Union[MetaOapg.properties.additional_data, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["default"]) -> typing.Union[MetaOapg.properties.default, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["field"]) -> typing.Union[MetaOapg.properties.field, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["help_text"]) -> typing.Union[MetaOapg.properties.help_text, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["identifier"]) -> typing.Union[MetaOapg.properties.identifier, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["section"]) -> typing.Union[MetaOapg.properties.section, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["additional_data", "default", "field", "help_text", "id", "identifier", "name", "section", "value", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            additional_data: typing.Union[MetaOapg.properties.additional_data, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            default: typing.Union[MetaOapg.properties.default, str, schemas.Unset] = schemas.unset,
                            field: typing.Union[MetaOapg.properties.field, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            help_text: typing.Union[MetaOapg.properties.help_text, str, schemas.Unset] = schemas.unset,
                            id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                            identifier: typing.Union[MetaOapg.properties.identifier, str, schemas.Unset] = schemas.unset,
                            name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                            section: typing.Union[MetaOapg.properties.section, str, schemas.Unset] = schemas.unset,
                            value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                additional_data=additional_data,
                                default=default,
                                field=field,
                                help_text=help_text,
                                id=id,
                                identifier=identifier,
                                name=name,
                                section=section,
                                value=value,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'data':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        data: typing.Union[MetaOapg.properties.data, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationVndApijson,
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/vnd.api+json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationVndApijson),
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
}
_all_accept_content_types = (
    'application/vnd.api+json',
    'application/json',
)


class BaseApi(api_client.Api):

    def _preferences_bulk_create_oapg(
        self: api_client.Api,
        body: typing.Union[SchemaForRequestBodyApplicationVndApijson, dict, frozendict.frozendict, SchemaForRequestBodyApplicationJson, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        query_params: RequestQueryParams = frozendict.frozendict(),
        content_type: str = 'application/vnd.api+json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_format,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        _fields = None
        _body = None
        if body is not schemas.unset:
            serialized_data = request_body_any_type.serialize(body, content_type)
            _headers.add('Content-Type', content_type)
            if 'fields' in serialized_data:
                _fields = serialized_data['fields']
            elif 'body' in serialized_data:
                _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class PreferencesBulkCreate(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def preferences_bulk_create(
        self: BaseApi,
        body: typing.Union[SchemaForRequestBodyApplicationVndApijson, dict, frozendict.frozendict, SchemaForRequestBodyApplicationJson, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        query_params: RequestQueryParams = frozendict.frozendict(),
        content_type: str = 'application/vnd.api+json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._preferences_bulk_create_oapg(
            body=body,
            query_params=query_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def post(
        self: BaseApi,
        body: typing.Union[SchemaForRequestBodyApplicationVndApijson, dict, frozendict.frozendict, SchemaForRequestBodyApplicationJson, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        query_params: RequestQueryParams = frozendict.frozendict(),
        content_type: str = 'application/vnd.api+json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._preferences_bulk_create_oapg(
            body=body,
            query_params=query_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class PagesReorder(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "pages",
        }
        
        class properties:
            
            
            class pages(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PageReorder']:
                        return PageReorder
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['PageReorder'], typing.List['PageReorder']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'pages':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PageReorder':
                    return super().__getitem__(i)
            __annotations__ = {
                "pages": pages,
            }
    
    pages: MetaOapg.properties.pages
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pages"]) -> MetaOapg.properties.pages: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["pages", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pages"]) -> MetaOapg.properties.pages: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["pages", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        pages: typing.Union[MetaOapg.properties.pages, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PagesReorder':
        return super().__new__(
            cls,
            *args,
            pages=pages,
            _configuration=_configuration,
            **kwargs,
        )

from papermerge_restapi_client.model.page_reorder import PageReorder



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from papermerge_restapi_client.paths.api_groups_.post import GroupsCreate
from papermerge_restapi_client.paths.api_groups_id_.delete import GroupsDestroy
from papermerge_restapi_client.paths.api_groups_.get import GroupsList
from papermerge_restapi_client.paths.api_groups_id_.patch import GroupsPartialUpdate
from papermerge_restapi_client.paths.api_groups_id_.get import GroupsRetrieve


class GroupsApi(
    GroupsCreate,
    GroupsDestroy,
    GroupsList,
    GroupsPartialUpdate,
    GroupsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from papermerge_restapi_client.paths.api_documents_id_ocr_text.get import DocumentOcrText
from papermerge_restapi_client.paths.api_documents_id_.delete import DocumentsDestroy
from papermerge_restapi_client.paths.api_documents_.get import DocumentsList
from papermerge_restapi_client.paths.api_documents_merge_.post import DocumentsMerge
from papermerge_restapi_client.paths.api_documents_id_.patch import DocumentsPartialUpdate
from papermerge_restapi_client.paths.api_documents_id_.get import DocumentsRetrieve
from papermerge_restapi_client.paths.api_documents_document_id_upload_file_name.put import UploadFile


class DocumentsApi(
    DocumentOcrText,
    DocumentsDestroy,
    DocumentsList,
    DocumentsMerge,
    DocumentsPartialUpdate,
    DocumentsRetrieve,
    UploadFile,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class PatchedTag(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "type",
        }
        
        class properties:
        
            @staticmethod
            def type() -> typing.Type['TagTypeEnum']:
                return TagTypeEnum
            id = schemas.UUIDSchema
            
            
            class attributes(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "name",
                    }
                    
                    class properties:
                        id = schemas.UUIDSchema
                        
                        
                        class name(
                            schemas.StrSchema
                        ):
                        
                        
                            class MetaOapg:
                                max_length = 100
                        
                        
                        class bg_color(
                            schemas.StrSchema
                        ):
                        
                        
                            class MetaOapg:
                                max_length = 7
                        
                        
                        class fg_color(
                            schemas.StrSchema
                        ):
                        
                        
                            class MetaOapg:
                                max_length = 7
                        
                        
                        class description(
                            schemas.StrBase,
                            schemas.NoneBase,
                            schemas.Schema,
                            schemas.NoneStrMixin
                        ):
                        
                        
                            class MetaOapg:
                                max_length = 1024
                        
                        
                            def __new__(
                                cls,
                                *args: typing.Union[None, str, ],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'description':
                                return super().__new__(
                                    cls,
                                    *args,
                                    _configuration=_configuration,
                                )
                        pinned = schemas.BoolSchema
                        __annotations__ = {
                            "id": id,
                            "name": name,
                            "bg_color": bg_color,
                            "fg_color": fg_color,
                            "description": description,
                            "pinned": pinned,
                        }
                
                name: MetaOapg.properties.name
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["bg_color"]) -> MetaOapg.properties.bg_color: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["fg_color"]) -> MetaOapg.properties.fg_color: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["pinned"]) -> MetaOapg.properties.pinned: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "name", "bg_color", "fg_color", "description", "pinned", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["bg_color"]) -> typing.Union[MetaOapg.properties.bg_color, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["fg_color"]) -> typing.Union[MetaOapg.properties.fg_color, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["pinned"]) -> typing.Union[MetaOapg.properties.pinned, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "name", "bg_color", "fg_color", "description", "pinned", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    name: typing.Union[MetaOapg.properties.name, str, ],
                    id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
                    bg_color: typing.Union[MetaOapg.properties.bg_color, str, schemas.Unset] = schemas.unset,
                    fg_color: typing.Union[MetaOapg.properties.fg_color, str, schemas.Unset] = schemas.unset,
                    description: typing.Union[MetaOapg.properties.description, None, str, schemas.Unset] = schemas.unset,
                    pinned: typing.Union[MetaOapg.properties.pinned, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'attributes':
                    return super().__new__(
                        cls,
                        *args,
                        name=name,
                        id=id,
                        bg_color=bg_color,
                        fg_color=fg_color,
                        description=description,
                        pinned=pinned,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "type": type,
                "id": id,
                "attributes": attributes,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    type: 'TagTypeEnum'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'TagTypeEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["attributes"]) -> MetaOapg.properties.attributes: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type"], typing_extensions.Literal["id"], typing_extensions.Literal["attributes"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'TagTypeEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["attributes"]) -> typing.Union[MetaOapg.properties.attributes, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type"], typing_extensions.Literal["id"], typing_extensions.Literal["attributes"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        type: 'TagTypeEnum',
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        attributes: typing.Union[MetaOapg.properties.attributes, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'PatchedTag':
        return super().__new__(
            cls,
            *args,
            type=type,
            id=id,
            attributes=attributes,
            _configuration=_configuration,
        )

from papermerge_restapi_client.model.tag_type_enum import TagTypeEnum



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.0b12
    Generated by: https://openapi-generator.tech
"""

import unittest

import papermerge_restapi_client
from papermerge_restapi_client.model.node_move import NodeMove
from papermerge_restapi_client import configuration


class TestNodeMove(unittest.TestCase):
    """NodeMove unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class Error(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.StrSchema
            status = schemas.StrSchema
        
            @staticmethod
            def links() -> typing.Type['Links']:
                return Links
            code = schemas.StrSchema
            title = schemas.StrSchema
            detail = schemas.StrSchema
            
            
            class source(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        pointer = schemas.StrSchema
                        parameter = schemas.StrSchema
                    
                        @staticmethod
                        def meta() -> typing.Type['Meta']:
                            return Meta
                        __annotations__ = {
                            "pointer": pointer,
                            "parameter": parameter,
                            "meta": meta,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["pointer"]) -> MetaOapg.properties.pointer: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["parameter"]) -> MetaOapg.properties.parameter: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["meta"]) -> 'Meta': ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["pointer", "parameter", "meta", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["pointer"]) -> typing.Union[MetaOapg.properties.pointer, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["parameter"]) -> typing.Union[MetaOapg.properties.parameter, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["meta"]) -> typing.Union['Meta', schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["pointer", "parameter", "meta", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    pointer: typing.Union[MetaOapg.properties.pointer, str, schemas.Unset] = schemas.unset,
                    parameter: typing.Union[MetaOapg.properties.parameter, str, schemas.Unset] = schemas.unset,
                    meta: typing.Union['Meta', schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'source':
                    return super().__new__(
                        cls,
                        *args,
                        pointer=pointer,
                        parameter=parameter,
                        meta=meta,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "id": id,
                "status": status,
                "links": links,
                "code": code,
                "title": title,
                "detail": detail,
                "source": source,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["links"]) -> 'Links': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["code"]) -> MetaOapg.properties.code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["detail"]) -> MetaOapg.properties.detail: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source"]) -> MetaOapg.properties.source: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id"], typing_extensions.Literal["status"], typing_extensions.Literal["links"], typing_extensions.Literal["code"], typing_extensions.Literal["title"], typing_extensions.Literal["detail"], typing_extensions.Literal["source"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["links"]) -> typing.Union['Links', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["code"]) -> typing.Union[MetaOapg.properties.code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> typing.Union[MetaOapg.properties.title, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["detail"]) -> typing.Union[MetaOapg.properties.detail, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> typing.Union[MetaOapg.properties.source, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id"], typing_extensions.Literal["status"], typing_extensions.Literal["links"], typing_extensions.Literal["code"], typing_extensions.Literal["title"], typing_extensions.Literal["detail"], typing_extensions.Literal["source"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
        links: typing.Union['Links', schemas.Unset] = schemas.unset,
        code: typing.Union[MetaOapg.properties.code, str, schemas.Unset] = schemas.unset,
        title: typing.Union[MetaOapg.properties.title, str, schemas.Unset] = schemas.unset,
        detail: typing.Union[MetaOapg.properties.detail, str, schemas.Unset] = schemas.unset,
        source: typing.Union[MetaOapg.properties.source, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Error':
        return super().__new__(
            cls,
            *args,
            id=id,
            status=status,
            links=links,
            code=code,
            title=title,
            detail=detail,
            source=source,
            _configuration=_configuration,
        )

from papermerge_restapi_client.model.links import Links
from papermerge_restapi_client.model.meta import Meta



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from papermerge_restapi_client.paths.api_tags_.post import TagsCreate
from papermerge_restapi_client.paths.api_tags_id_.delete import TagsDestroy
from papermerge_restapi_client.paths.api_tags_.get import TagsList
from papermerge_restapi_client.paths.api_tags_id_.patch import TagsPartialUpdate
from papermerge_restapi_client.paths.api_tags_id_.get import TagsRetrieve


class TagsApi(
    TagsCreate,
    TagsDestroy,
    TagsList,
    TagsPartialUpdate,
    TagsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3

from papermerge_restapi_client import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401

from . import path

# query params


class FormatSchema(
    schemas.EnumBase,
    schemas.StrSchema
):


    class MetaOapg:
        enum_value_to_name = {
            "json": "JSON",
            "vnd.api+json": "VND_APIJSON",
        }
    
    @schemas.classproperty
    def JSON(cls):
        return cls("json")
    
    @schemas.classproperty
    def VND_APIJSON(cls):
        return cls("vnd.api+json")
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'format': typing.Union[FormatSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_format = api_client.QueryParameter(
    name="format",
    style=api_client.ParameterStyle.FORM,
    schema=FormatSchema,
    explode=True,
)
_auth = [
    'Token Authentication',
]


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
)
_status_code_to_response = {
    '200': _response_for_200,
}


class BaseApi(api_client.Api):

    def _auth_logoutall_create_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_format,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value
        # TODO add cookie handling

        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class AuthLogoutallCreate(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def auth_logoutall_create(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._auth_logoutall_create_oapg(
            query_params=query_params,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def post(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._auth_logoutall_create_oapg(
            query_params=query_params,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from papermerge_restapi_client.paths.api_nodes_id_tags_.post import ApiForpost
from papermerge_restapi_client.paths.api_nodes_id_tags_.delete import ApiFordelete
from papermerge_restapi_client.paths.api_nodes_id_tags_.patch import ApiForpatch


class ApiNodesIdTags(
    ApiForpost,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from papermerge_restapi_client import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401

from papermerge_restapi_client.model.data_node import DataNode

from . import path

# body param
SchemaForRequestBodyApplicationVndApijson = DataNode


request_body_data_node = api_client.RequestBody(
    content={
        'application/vnd.api+json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationVndApijson),
    },
    required=True,
)
_auth = [
    'Token Authentication',
]
SchemaFor201ResponseBodyApplicationVndApijson = DataNode


@dataclass
class ApiResponseFor201(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor201ResponseBodyApplicationVndApijson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_201 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor201,
    content={
        'application/vnd.api+json': api_client.MediaType(
            schema=SchemaFor201ResponseBodyApplicationVndApijson),
    },
)


class SchemaFor400ResponseBodyApplicationVndApijson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            
            
            class errors(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                detail = schemas.StrSchema
                                status = schemas.StrSchema
                                code = schemas.StrSchema
                                
                                
                                class source(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            pointer = schemas.StrSchema
                                            __annotations__ = {
                                                "pointer": pointer,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["pointer"]) -> MetaOapg.properties.pointer: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["pointer", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["pointer"]) -> typing.Union[MetaOapg.properties.pointer, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["pointer", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        pointer: typing.Union[MetaOapg.properties.pointer, str, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'source':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            pointer=pointer,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                __annotations__ = {
                                    "detail": detail,
                                    "status": status,
                                    "code": code,
                                    "source": source,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["detail"]) -> MetaOapg.properties.detail: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["code"]) -> MetaOapg.properties.code: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["source"]) -> MetaOapg.properties.source: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["detail", "status", "code", "source", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["detail"]) -> typing.Union[MetaOapg.properties.detail, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["code"]) -> typing.Union[MetaOapg.properties.code, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> typing.Union[MetaOapg.properties.source, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["detail", "status", "code", "source", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            detail: typing.Union[MetaOapg.properties.detail, str, schemas.Unset] = schemas.unset,
                            status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
                            code: typing.Union[MetaOapg.properties.code, str, schemas.Unset] = schemas.unset,
                            source: typing.Union[MetaOapg.properties.source, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                detail=detail,
                                status=status,
                                code=code,
                                source=source,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'errors':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "errors": errors,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errors"]) -> MetaOapg.properties.errors: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["errors", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errors"]) -> typing.Union[MetaOapg.properties.errors, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["errors", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        errors: typing.Union[MetaOapg.properties.errors, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor400ResponseBodyApplicationVndApijson':
        return super().__new__(
            cls,
            *args,
            errors=errors,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationVndApijson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/vnd.api+json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationVndApijson),
    },
)
_status_code_to_response = {
    '201': _response_for_201,
    '400': _response_for_400,
}
_all_accept_content_types = (
    'application/vnd.api+json',
)


class BaseApi(api_client.Api):

    def _nodes_create_oapg(
        self: api_client.Api,
        body: typing.Union[SchemaForRequestBodyApplicationVndApijson, ],
        content_type: str = 'application/vnd.api+json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor201,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        used_path = path.value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        if body is schemas.unset:
            raise exceptions.ApiValueError(
                'The required body parameter has an invalid value of: unset. Set a valid value instead')
        _fields = None
        _body = None
        serialized_data = request_body_data_node.serialize(body, content_type)
        _headers.add('Content-Type', content_type)
        if 'fields' in serialized_data:
            _fields = serialized_data['fields']
        elif 'body' in serialized_data:
            _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class NodesCreate(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def nodes_create(
        self: BaseApi,
        body: typing.Union[SchemaForRequestBodyApplicationVndApijson, ],
        content_type: str = 'application/vnd.api+json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor201,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._nodes_create_oapg(
            body=body,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def post(
        self: BaseApi,
        body: typing.Union[SchemaForRequestBodyApplicationVndApijson, ],
        content_type: str = 'application/vnd.api+json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor201,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._nodes_create_oapg(
            body=body,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from papermerge_restapi_client.paths.api_pages_id_.get import ApiForget
from papermerge_restapi_client.paths.api_pages_id_.delete import ApiFordelete


class ApiPagesId(
    ApiForget,
    ApiFordelete,
):
    pass



from papermerge_restapi_client.paths.api_groups_.get import ApiForget
from papermerge_restapi_client.paths.api_groups_.post import ApiForpost


class ApiGroups(
    ApiForget,
    ApiForpost,
):
    pass



from papermerge_restapi_client.paths.api_tokens_.get import ApiForget
from papermerge_restapi_client.paths.api_tokens_.post import ApiForpost


class ApiTokens(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from papermerge_restapi_client.paths.api_pages_move_to_document_.post import MoveToDocument
from papermerge_restapi_client.paths.api_pages_move_to_folder_.post import MoveToFolder
from papermerge_restapi_client.paths.api_pages_.delete import MultiplePagesDelete
from papermerge_restapi_client.paths.api_pages_reorder_.post import Reorder
from papermerge_restapi_client.paths.api_pages_id_.get import Retrieve
from papermerge_restapi_client.paths.api_pages_rotate_.post import Rotate
from papermerge_restapi_client.paths.api_pages_id_.delete import SinglePageDelete


class PagesApi(
    MoveToDocument,
    MoveToFolder,
    MultiplePagesDelete,
    Reorder,
    Retrieve,
    Rotate,
    SinglePageDelete,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from papermerge_restapi_client.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    AUTH = "auth"
    DOCUMENTVERSIONS = "document-versions"
    DOCUMENTS = "documents"
    FOLDERS = "folders"
    GROUPS = "groups"
    NODES = "nodes"
    OCR = "ocr"
    PAGES = "pages"
    PERMISSIONS = "permissions"
    PREFERENCES = "preferences"
    SCHEMA = "schema"
    SEARCH = "search"
    TAGS = "tags"
    TOKENS = "tokens"
    USERS = "users"
    VERSION = "version"



from papermerge_restapi_client.paths.api_folders_id_.get import ApiForget
from papermerge_restapi_client.paths.api_folders_id_.delete import ApiFordelete
from papermerge_restapi_client.paths.api_folders_id_.patch import ApiForpatch


class ApiFoldersId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from papermerge_restapi_client.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    API_AUTH_LOGIN_ = "/api/auth/login/"
    API_AUTH_LOGOUT_ = "/api/auth/logout/"
    API_AUTH_LOGOUTALL_ = "/api/auth/logoutall/"
    API_DOCUMENTVERSIONS_ID_ = "/api/document-versions/{id}/"
    API_DOCUMENTVERSIONS_ID_DOWNLOAD_ = "/api/document-versions/{id}/download/"
    API_DOCUMENTS_ = "/api/documents/"
    API_DOCUMENTS_DOCUMENT_ID_UPLOAD_FILE_NAME = "/api/documents/{document_id}/upload/{file_name}"
    API_DOCUMENTS_ID_ = "/api/documents/{id}/"
    API_DOCUMENTS_ID_OCRTEXT = "/api/documents/{id}/ocr-text"
    API_DOCUMENTS_MERGE_ = "/api/documents/merge/"
    API_FOLDERS_ = "/api/folders/"
    API_FOLDERS_ID_ = "/api/folders/{id}/"
    API_GROUPS_ = "/api/groups/"
    API_GROUPS_ID_ = "/api/groups/{id}/"
    API_NODES_ = "/api/nodes/"
    API_NODES_ID_ = "/api/nodes/{id}/"
    API_NODES_ID_TAGS_ = "/api/nodes/{id}/tags/"
    API_NODES_DOWNLOAD_ = "/api/nodes/download/"
    API_NODES_INBOXCOUNT_ = "/api/nodes/inboxcount/"
    API_NODES_MOVE_ = "/api/nodes/move/"
    API_OCR_ = "/api/ocr/"
    API_PAGES_ = "/api/pages/"
    API_PAGES_ID_ = "/api/pages/{id}/"
    API_PAGES_MOVETODOCUMENT_ = "/api/pages/move-to-document/"
    API_PAGES_MOVETOFOLDER_ = "/api/pages/move-to-folder/"
    API_PAGES_REORDER_ = "/api/pages/reorder/"
    API_PAGES_ROTATE_ = "/api/pages/rotate/"
    API_PERMISSIONS_ = "/api/permissions/"
    API_PREFERENCES_ = "/api/preferences/"
    API_PREFERENCES_ID_ = "/api/preferences/{id}/"
    API_PREFERENCES_BULK_ = "/api/preferences/bulk/"
    API_SCHEMA_ = "/api/schema/"
    API_SEARCH_ = "/api/search/"
    API_TAGS_ = "/api/tags/"
    API_TAGS_ID_ = "/api/tags/{id}/"
    API_TOKENS_ = "/api/tokens/"
    API_TOKENS_DIGEST_ = "/api/tokens/{digest}/"
    API_USERS_ = "/api/users/"
    API_USERS_ID_ = "/api/users/{id}/"
    API_USERS_ID_CHANGEPASSWORD_ = "/api/users/{id}/change-password/"
    API_USERS_ME_ = "/api/users/me/"
    API_VERSION_ = "/api/version/"



import typing_extensions

from papermerge_restapi_client.paths import PathValues
from papermerge_restapi_client.apis.paths.api_auth_login_ import ApiAuthLogin
from papermerge_restapi_client.apis.paths.api_auth_logout_ import ApiAuthLogout
from papermerge_restapi_client.apis.paths.api_auth_logoutall_ import ApiAuthLogoutall
from papermerge_restapi_client.apis.paths.api_document_versions_id_ import ApiDocumentVersionsId
from papermerge_restapi_client.apis.paths.api_document_versions_id_download_ import ApiDocumentVersionsIdDownload
from papermerge_restapi_client.apis.paths.api_documents_ import ApiDocuments
from papermerge_restapi_client.apis.paths.api_documents_document_id_upload_file_name import ApiDocumentsDocumentIdUploadFileName
from papermerge_restapi_client.apis.paths.api_documents_id_ import ApiDocumentsId
from papermerge_restapi_client.apis.paths.api_documents_id_ocr_text import ApiDocumentsIdOcrText
from papermerge_restapi_client.apis.paths.api_documents_merge_ import ApiDocumentsMerge
from papermerge_restapi_client.apis.paths.api_folders_ import ApiFolders
from papermerge_restapi_client.apis.paths.api_folders_id_ import ApiFoldersId
from papermerge_restapi_client.apis.paths.api_groups_ import ApiGroups
from papermerge_restapi_client.apis.paths.api_groups_id_ import ApiGroupsId
from papermerge_restapi_client.apis.paths.api_nodes_ import ApiNodes
from papermerge_restapi_client.apis.paths.api_nodes_id_ import ApiNodesId
from papermerge_restapi_client.apis.paths.api_nodes_id_tags_ import ApiNodesIdTags
from papermerge_restapi_client.apis.paths.api_nodes_download_ import ApiNodesDownload
from papermerge_restapi_client.apis.paths.api_nodes_inboxcount_ import ApiNodesInboxcount
from papermerge_restapi_client.apis.paths.api_nodes_move_ import ApiNodesMove
from papermerge_restapi_client.apis.paths.api_ocr_ import ApiOcr
from papermerge_restapi_client.apis.paths.api_pages_ import ApiPages
from papermerge_restapi_client.apis.paths.api_pages_id_ import ApiPagesId
from papermerge_restapi_client.apis.paths.api_pages_move_to_document_ import ApiPagesMoveToDocument
from papermerge_restapi_client.apis.paths.api_pages_move_to_folder_ import ApiPagesMoveToFolder
from papermerge_restapi_client.apis.paths.api_pages_reorder_ import ApiPagesReorder
from papermerge_restapi_client.apis.paths.api_pages_rotate_ import ApiPagesRotate
from papermerge_restapi_client.apis.paths.api_permissions_ import ApiPermissions
from papermerge_restapi_client.apis.paths.api_preferences_ import ApiPreferences
from papermerge_restapi_client.apis.paths.api_preferences_id_ import ApiPreferencesId
from papermerge_restapi_client.apis.paths.api_preferences_bulk_ import ApiPreferencesBulk
from papermerge_restapi_client.apis.paths.api_schema_ import ApiSchema
from papermerge_restapi_client.apis.paths.api_search_ import ApiSearch
from papermerge_restapi_client.apis.paths.api_tags_ import ApiTags
from papermerge_restapi_client.apis.paths.api_tags_id_ import ApiTagsId
from papermerge_restapi_client.apis.paths.api_tokens_ import ApiTokens
from papermerge_restapi_client.apis.paths.api_tokens_digest_ import ApiTokensDigest
from papermerge_restapi_client.apis.paths.api_users_ import ApiUsers
from papermerge_restapi_client.apis.paths.api_users_id_ import ApiUsersId
from papermerge_restapi_client.apis.paths.api_users_id_change_password_ import ApiUsersIdChangePassword
from papermerge_restapi_client.apis.paths.api_users_me_ import ApiUsersMe
from papermerge_restapi_client.apis.paths.api_version_ import ApiVersion

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.API_AUTH_LOGIN_: ApiAuthLogin,
        PathValues.API_AUTH_LOGOUT_: ApiAuthLogout,
        PathValues.API_AUTH_LOGOUTALL_: ApiAuthLogoutall,
        PathValues.API_DOCUMENTVERSIONS_ID_: ApiDocumentVersionsId,
        PathValues.API_DOCUMENTVERSIONS_ID_DOWNLOAD_: ApiDocumentVersionsIdDownload,
        PathValues.API_DOCUMENTS_: ApiDocuments,
        PathValues.API_DOCUMENTS_DOCUMENT_ID_UPLOAD_FILE_NAME: ApiDocumentsDocumentIdUploadFileName,
        PathValues.API_DOCUMENTS_ID_: ApiDocumentsId,
        PathValues.API_DOCUMENTS_ID_OCRTEXT: ApiDocumentsIdOcrText,
        PathValues.API_DOCUMENTS_MERGE_: ApiDocumentsMerge,
        PathValues.API_FOLDERS_: ApiFolders,
        PathValues.API_FOLDERS_ID_: ApiFoldersId,
        PathValues.API_GROUPS_: ApiGroups,
        PathValues.API_GROUPS_ID_: ApiGroupsId,
        PathValues.API_NODES_: ApiNodes,
        PathValues.API_NODES_ID_: ApiNodesId,
        PathValues.API_NODES_ID_TAGS_: ApiNodesIdTags,
        PathValues.API_NODES_DOWNLOAD_: ApiNodesDownload,
        PathValues.API_NODES_INBOXCOUNT_: ApiNodesInboxcount,
        PathValues.API_NODES_MOVE_: ApiNodesMove,
        PathValues.API_OCR_: ApiOcr,
        PathValues.API_PAGES_: ApiPages,
        PathValues.API_PAGES_ID_: ApiPagesId,
        PathValues.API_PAGES_MOVETODOCUMENT_: ApiPagesMoveToDocument,
        PathValues.API_PAGES_MOVETOFOLDER_: ApiPagesMoveToFolder,
        PathValues.API_PAGES_REORDER_: ApiPagesReorder,
        PathValues.API_PAGES_ROTATE_: ApiPagesRotate,
        PathValues.API_PERMISSIONS_: ApiPermissions,
        PathValues.API_PREFERENCES_: ApiPreferences,
        PathValues.API_PREFERENCES_ID_: ApiPreferencesId,
        PathValues.API_PREFERENCES_BULK_: ApiPreferencesBulk,
        PathValues.API_SCHEMA_: ApiSchema,
        PathValues.API_SEARCH_: ApiSearch,
        PathValues.API_TAGS_: ApiTags,
        PathValues.API_TAGS_ID_: ApiTagsId,
        PathValues.API_TOKENS_: ApiTokens,
        PathValues.API_TOKENS_DIGEST_: ApiTokensDigest,
        PathValues.API_USERS_: ApiUsers,
        PathValues.API_USERS_ID_: ApiUsersId,
        PathValues.API_USERS_ID_CHANGEPASSWORD_: ApiUsersIdChangePassword,
        PathValues.API_USERS_ME_: ApiUsersMe,
        PathValues.API_VERSION_: ApiVersion,
    }
)

path_to_api = PathToApi(
    {
        PathValues.API_AUTH_LOGIN_: ApiAuthLogin,
        PathValues.API_AUTH_LOGOUT_: ApiAuthLogout,
        PathValues.API_AUTH_LOGOUTALL_: ApiAuthLogoutall,
        PathValues.API_DOCUMENTVERSIONS_ID_: ApiDocumentVersionsId,
        PathValues.API_DOCUMENTVERSIONS_ID_DOWNLOAD_: ApiDocumentVersionsIdDownload,
        PathValues.API_DOCUMENTS_: ApiDocuments,
        PathValues.API_DOCUMENTS_DOCUMENT_ID_UPLOAD_FILE_NAME: ApiDocumentsDocumentIdUploadFileName,
        PathValues.API_DOCUMENTS_ID_: ApiDocumentsId,
        PathValues.API_DOCUMENTS_ID_OCRTEXT: ApiDocumentsIdOcrText,
        PathValues.API_DOCUMENTS_MERGE_: ApiDocumentsMerge,
        PathValues.API_FOLDERS_: ApiFolders,
        PathValues.API_FOLDERS_ID_: ApiFoldersId,
        PathValues.API_GROUPS_: ApiGroups,
        PathValues.API_GROUPS_ID_: ApiGroupsId,
        PathValues.API_NODES_: ApiNodes,
        PathValues.API_NODES_ID_: ApiNodesId,
        PathValues.API_NODES_ID_TAGS_: ApiNodesIdTags,
        PathValues.API_NODES_DOWNLOAD_: ApiNodesDownload,
        PathValues.API_NODES_INBOXCOUNT_: ApiNodesInboxcount,
        PathValues.API_NODES_MOVE_: ApiNodesMove,
        PathValues.API_OCR_: ApiOcr,
        PathValues.API_PAGES_: ApiPages,
        PathValues.API_PAGES_ID_: ApiPagesId,
        PathValues.API_PAGES_MOVETODOCUMENT_: ApiPagesMoveToDocument,
        PathValues.API_PAGES_MOVETOFOLDER_: ApiPagesMoveToFolder,
        PathValues.API_PAGES_REORDER_: ApiPagesReorder,
        PathValues.API_PAGES_ROTATE_: ApiPagesRotate,
        PathValues.API_PERMISSIONS_: ApiPermissions,
        PathValues.API_PREFERENCES_: ApiPreferences,
        PathValues.API_PREFERENCES_ID_: ApiPreferencesId,
        PathValues.API_PREFERENCES_BULK_: ApiPreferencesBulk,
        PathValues.API_SCHEMA_: ApiSchema,
        PathValues.API_SEARCH_: ApiSearch,
        PathValues.API_TAGS_: ApiTags,
        PathValues.API_TAGS_ID_: ApiTagsId,
        PathValues.API_TOKENS_: ApiTokens,
        PathValues.API_TOKENS_DIGEST_: ApiTokensDigest,
        PathValues.API_USERS_: ApiUsers,
        PathValues.API_USERS_ID_: ApiUsersId,
        PathValues.API_USERS_ID_CHANGEPASSWORD_: ApiUsersIdChangePassword,
        PathValues.API_USERS_ME_: ApiUsersMe,
        PathValues.API_VERSION_: ApiVersion,
    }
)



from papermerge_restapi_client.paths.api_tags_id_.get import ApiForget
from papermerge_restapi_client.paths.api_tags_id_.delete import ApiFordelete
from papermerge_restapi_client.paths.api_tags_id_.patch import ApiForpatch


class ApiTagsId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class NodeMove(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "nodes",
            "target_parent",
        }
        
        class properties:
        
            @staticmethod
            def target_parent() -> typing.Type['NodeID']:
                return NodeID
            
            
            class nodes(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['NodeID']:
                        return NodeID
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['NodeID'], typing.List['NodeID']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'nodes':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'NodeID':
                    return super().__getitem__(i)
            __annotations__ = {
                "target_parent": target_parent,
                "nodes": nodes,
            }
    
    nodes: MetaOapg.properties.nodes
    target_parent: 'NodeID'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["target_parent"]) -> 'NodeID': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nodes"]) -> MetaOapg.properties.nodes: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["target_parent", "nodes", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["target_parent"]) -> 'NodeID': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nodes"]) -> MetaOapg.properties.nodes: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["target_parent", "nodes", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        nodes: typing.Union[MetaOapg.properties.nodes, list, tuple, ],
        target_parent: 'NodeID',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NodeMove':
        return super().__new__(
            cls,
            *args,
            nodes=nodes,
            target_parent=target_parent,
            _configuration=_configuration,
            **kwargs,
        )

from papermerge_restapi_client.model.node_id import NodeID



from papermerge_restapi_client.paths.api_preferences_id_.get import ApiForget
from papermerge_restapi_client.paths.api_preferences_id_.put import ApiForput
from papermerge_restapi_client.paths.api_preferences_id_.patch import ApiForpatch


class ApiPreferencesId(
    ApiForget,
    ApiForput,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class Resource(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "id",
            "type",
        }
        
        class properties:
            type = schemas.StrSchema
            id = schemas.StrSchema
            attributes = schemas.DictSchema
            relationships = schemas.DictSchema
        
            @staticmethod
            def links() -> typing.Type['Links']:
                return Links
        
            @staticmethod
            def meta() -> typing.Type['Meta']:
                return Meta
            __annotations__ = {
                "type": type,
                "id": id,
                "attributes": attributes,
                "relationships": relationships,
                "links": links,
                "meta": meta,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    id: MetaOapg.properties.id
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["attributes"]) -> MetaOapg.properties.attributes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["relationships"]) -> MetaOapg.properties.relationships: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["links"]) -> 'Links': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["meta"]) -> 'Meta': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id"], typing_extensions.Literal["type"], typing_extensions.Literal["attributes"], typing_extensions.Literal["relationships"], typing_extensions.Literal["links"], typing_extensions.Literal["meta"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["attributes"]) -> typing.Union[MetaOapg.properties.attributes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["relationships"]) -> typing.Union[MetaOapg.properties.relationships, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["links"]) -> typing.Union['Links', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["meta"]) -> typing.Union['Meta', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id"], typing_extensions.Literal["type"], typing_extensions.Literal["attributes"], typing_extensions.Literal["relationships"], typing_extensions.Literal["links"], typing_extensions.Literal["meta"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        attributes: typing.Union[MetaOapg.properties.attributes, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        relationships: typing.Union[MetaOapg.properties.relationships, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        links: typing.Union['Links', schemas.Unset] = schemas.unset,
        meta: typing.Union['Meta', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Resource':
        return super().__new__(
            cls,
            *args,
            id=id,
            type=type,
            attributes=attributes,
            relationships=relationships,
            links=links,
            meta=meta,
            _configuration=_configuration,
        )

from papermerge_restapi_client.model.links import Links
from papermerge_restapi_client.model.meta import Meta



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class PagesMoveToFolder(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "pages",
            "dst",
        }
        
        class properties:
            
            
            class pages(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.UUIDSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'pages':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            dst = schemas.UUIDSchema
            single_page = schemas.BoolSchema
            
            
            class title_format(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 32
            __annotations__ = {
                "pages": pages,
                "dst": dst,
                "single_page": single_page,
                "title_format": title_format,
            }
    
    pages: MetaOapg.properties.pages
    dst: MetaOapg.properties.dst
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pages"]) -> MetaOapg.properties.pages: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dst"]) -> MetaOapg.properties.dst: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["single_page"]) -> MetaOapg.properties.single_page: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title_format"]) -> MetaOapg.properties.title_format: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["pages", "dst", "single_page", "title_format", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pages"]) -> MetaOapg.properties.pages: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dst"]) -> MetaOapg.properties.dst: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["single_page"]) -> typing.Union[MetaOapg.properties.single_page, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title_format"]) -> typing.Union[MetaOapg.properties.title_format, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["pages", "dst", "single_page", "title_format", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        pages: typing.Union[MetaOapg.properties.pages, list, tuple, ],
        dst: typing.Union[MetaOapg.properties.dst, str, uuid.UUID, ],
        single_page: typing.Union[MetaOapg.properties.single_page, bool, schemas.Unset] = schemas.unset,
        title_format: typing.Union[MetaOapg.properties.title_format, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PagesMoveToFolder':
        return super().__new__(
            cls,
            *args,
            pages=pages,
            dst=dst,
            single_page=single_page,
            title_format=title_format,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Papermerge REST API

    Document management system designed for digital archives  # noqa: E501

    The version of the OpenAPI document: 2.1.7.dev3
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from papermerge_restapi_client import schemas  # noqa: F401


class Pageref(
    schemas.ComposedSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        one_of_0 = schemas.StrSchema
        
        
        class one_of_1(
            schemas.DictBase,
            schemas.NoneBase,
            schemas.Schema,
            schemas.NoneFrozenDictMixin
        ):
        
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, None, ],
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'one_of_1':
                return super().__new__(
                    cls,
                    *args,
                    _configuration=_configuration,
                    **kwargs,
                )
        
        @classmethod
        @functools.lru_cache()
        def one_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                cls.one_of_0,
                cls.one_of_1,
            ]


    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Pageref':
        return super().__new__(
            cls,
            *args,
            _configuration=_configuration,
            **kwargs,
        )
